import React, { useState, useRef, useEffect, useMemo } from "react";
import {
    Edit,
    SimpleForm,
    FormDataConsumer,
    useTranslate,
    TextInput,
    NumberInput,
    BooleanInput,
    DateInput,
    SelectInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    SaveButton,
    Toolbar,
    Labeled,
    NumberField,
    required,
    useGetOne,
    useRecordContext,
    DeleteButton,
    Form,
    EditBase,
} from 'react-admin';
import { useWatch, useFormContext } from "react-hook-form";
import { Stack, Grid, Box, Typography, Dialog, DialogActions, DialogContent, DialogTitle } from '@mui/material';
import { EDIT_MODE, REFERENCE_INPUT_PAGESIZE } from '@/config/setting';
import CustomerTopToolBar from "../../components/EditTopToolBar";
import DialogCloseButton from "../../components/DialogCloseButton";
import StatusSelectInput from "../../components/StatusSelectInput";
import MemoInput from "../../components/MemoInput";


const FormToolbar = () => {
    const { getValues } = useFormContext();

    return (
        <Toolbar sx={{ justifyContent: 'space-between' }}>
            <SaveButton />
            <DeleteButton mutationMode="optimistic" />
        </Toolbar>
    )
}

const PurchaseItemEdit = (props) => {
    const { open, setOpen, record } = props;
    const translate = useTranslate();
    const handleClose = (event, reason) => {
        if (reason !== "backdropClick") {
            setOpen(false);
        }
    };
    const { data, isPending, } = useGetOne('purchaseItem', { id: record?.id });
    if (data == null || data == undefined) { return }

    return (
        <>
            <Dialog
                open={open}
                onClose={handleClose}
                aria-labelledby="form-dialog-title"
                fullWidth
                disableRestoreFocus
                maxWidth="md"
            >
                <DialogTitle id="form-dialog-title" sx={{
                    position: 'sticky',
                    top: 0,
                    backgroundColor: 'background.paper',
                    zIndex: 1000
                }}
                >
                    {translate('update.title')}
                    <Box sx={{ position: 'absolute', top: 8, right: 8, zIndex: 1001 }}>
                        <DialogCloseButton onClose={handleClose} />
                    </Box>
                </DialogTitle>
                <EditBase
                    resource="purchaseItem"
                    mutationMode={EDIT_MODE}
                    actions={<CustomerTopToolBar />}
                >
                    <Form
                        shouldUnregister
                        warnWhenUnsavedChanges
                        toolbar={<FormToolbar />}
                        mode="onTouched"
                        defaultValues={{}}
                    >
                        <DialogContent sx={{ mt: 2 }}>

                            <Grid container width={{ xs: '100%', xl: '100%' }} rowSpacing={3} columnSpacing={3}>
                                <Grid item xs={12} md={8} gap={2}>
                                    <Typography variant="h6" gutterBottom>
                                        {translate('common.edit.title.main')}
                                    </Typography>
                                    <Stack direction='row' gap={2}>
                                        <NumberInput
                                            label="table.field.purchaseItem.purchaseId"
                                            source="purchaseId"
                                            defaultValue={record?.id}
                                        />
                                        <TextInput
                                            label="table.field.purchaseItem.platItemId"
                                            source="platItemId"
                                            parse={v => v}
                                        />
                                        <TextInput
                                            label="table.field.purchaseItem.matnrCode"
                                            source="matnrCode"
                                            parse={v => v}
                                        />
                                    </Stack>
                                    <Stack direction='row' gap={2}>
                                        <TextInput
                                            label="table.field.purchaseItem.matnrName"
                                            source="matnrName"
                                            parse={v => v}
                                        />
                                        <TextInput
                                            label="table.field.purchaseItem.unit"
                                            source="unit"
                                            parse={v => v}
                                        />
                                        <NumberInput
                                            label="table.field.purchaseItem.anfme"
                                            source="anfme"
                                            validate={required()}
                                        />
                                    </Stack>
                                    <Stack direction='row' gap={2}>
                                        <NumberInput
                                            label="table.field.purchaseItem.qty"
                                            source="qty"
                                            validate={required()}
                                        />
                                        <NumberInput
                                            label="table.field.purchaseItem.nromQty"
                                            source="nromQty"
                                            validate={required()}
                                        />
                                        <NumberInput
                                            label="table.field.purchaseItem.asnQty"
                                            source="asnQty"
                                            validate={required()}
                                        />
                                    </Stack>
                                    <Stack direction='row' gap={2}>
                                        <NumberInput
                                            label="table.field.purchaseItem.printQty"
                                            source="printQty"
                                            validate={required()}
                                        />
                                        <TextInput
                                            label="table.field.purchaseItem.splrName"
                                            source="splrName"
                                            parse={v => v}
                                        />
                                        <TextInput
                                            label="table.field.purchaseItem.splrCode"
                                            source="splrCode"
                                            parse={v => v}
                                        />
                                        <TextInput
                                            label="table.field.purchaseItem.splrBatch"
                                            source="splrBatch"
                                            parse={v => v}
                                        />
                                    </Stack>
                                </Grid>
                                <Grid item xs={12} md={4} >
                                    <Typography variant="h6" gutterBottom>
                                        {translate('common.edit.title.common')}
                                    </Typography>
                                    <StatusSelectInput />
                                    <Box mt="2em" />
                                    <MemoInput />
                                </Grid>
                            </Grid>
                        </DialogContent>
                        <DialogActions sx={{ position: 'sticky', bottom: 0, backgroundColor: 'background.paper', zIndex: 1000 }}>
                            <Toolbar sx={{ width: '100%', justifyContent: 'end' }}  >
                                <SaveButton type="button" mutationOptions={{
                                    onSuccess: () => {
                                        setOpen(false)
                                    }
                                }} />
                            </Toolbar>
                        </DialogActions>
                    </Form>
                </EditBase >
            </Dialog>
        </>
    )
}

export default PurchaseItemEdit;
